pub struct DatabaseInstance {
pub database_url: Option<String>,
pub name: Option<String>,
pub project: Option<String>,
pub state: Option<String>,
pub type_: Option<String>,
}Expand description
Representation of a Realtime Database instance. Details on interacting with contents of a DatabaseInstance can be found at: https://firebase.google.com/docs/database/rest/start.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations instances create projects (request|response)
- locations instances delete projects (response)
- locations instances disable projects (response)
- locations instances get projects (response)
- locations instances reenable projects (response)
- locations instances undelete projects (response)
Fields
database_url: Option<String>Output only. Output Only. The globally unique hostname of the database.
name: Option<String>The fully qualified resource name of the database instance, in the form: projects/{project-number}/locations/{location-id}/instances/{database-id}.
project: Option<String>Output only. The resource name of the project this instance belongs to. For example: projects/{project-number}.
state: Option<String>Output only. The database’s lifecycle state. Read-only.
type_: Option<String>Immutable. The database instance type. On creation only USER_DATABASE is allowed, which is also the default when omitted.